==> legalios-0.0.7.crate: legalios-0.0.7/src/service_tests.rs <==
pub mod example_01_health_01_min_monthly_basis_test;
pub mod example_01_health_02_max_annuals_basis_test;
pub mod example_01_health_03_lim_monthly_state_test;
pub mod example_01_health_04_lim_monthly_dis50_test;
pub mod example_01_health_05_factor_compound_test;
pub mod example_01_health_06_factor_employee_test;
pub mod example_01_health_07_margin_income_emp_test;
pub mod example_01_health_08_margin_income_agr_test;
pub mod example_02_salary_01_working_shift_week_test;
pub mod example_02_salary_02_working_shift_time_test;
pub mod example_02_salary_03_min_monthly_wage_test;
pub mod example_02_salary_04_min_hourly_wage_test;
pub mod example_03_social_01_max_annuals_basis_test;
pub mod example_03_social_02_factor_employer_test;
pub mod example_03_social_03_factor_employer_higher_test;
pub mod example_03_social_04_factor_employee_test;
pub mod example_03_social_05_factor_employee_garant_test;
pub mod example_03_social_06_factor_employee_reduce_test;
pub mod example_03_social_07_margin_income_emp_test;
pub mod example_03_social_08_margin_income_agr_test;
pub mod example_04_taxing_01_allowance_payer_test;
pub mod example_04_taxing_02_allowance_disab1st_test;
pub mod example_04_taxing_03_allowance_disab2nd_test;
pub mod example_04_taxing_04_allowance_disab3rd_test;
pub mod example_04_taxing_05_allowance_study_test;
pub mod example_04_taxing_06_allowance_child1st_test;
pub mod example_04_taxing_07_allowance_child2nd_test;
pub mod example_04_taxing_08_allowance_child3rd_test;
pub mod example_04_taxing_09_factor_advances_test;
pub mod example_04_taxing_10_factor_withhold_test;
pub mod example_04_taxing_11_factor_solitary_test;
pub mod example_04_taxing_12_min_amount_of_tax_bonus_test;
pub mod example_04_taxing_13_max_amount_of_tax_bonus_test;
pub mod example_04_taxing_14_margin_income_of_tax_bonus_test;
pub mod example_04_taxing_15_margin_income_of_rounding_test;
pub mod example_04_taxing_16_margin_income_of_withhold_test;
pub mod example_04_taxing_17_margin_income_of_solitary_test;
pub mod example_04_taxing_18_margin_income_of_wth_emp_test;
pub mod example_04_taxing_19_margin_income_of_wth_agr_test;
pub mod service_examples_int_tests;
pub mod service_examples_dec_tests;
pub mod service_report_examples_int_tests;
pub mod service_report_examples_dec_tests;
pub mod service_report_examples_tests;

==> legalios-0.22.2.crate: legalios-0.22.2/src/service_tests.rs <==
pub mod example_01_health_01_min_monthly_basis_test;
pub mod example_01_health_02_max_annuals_basis_test;
pub mod example_01_health_03_lim_monthly_state_test;
pub mod example_01_health_04_lim_monthly_dis50_test;
pub mod example_01_health_05_factor_compound_test;
pub mod example_01_health_06_factor_employee_test;
pub mod example_01_health_07_margin_income_emp_test;
pub mod example_01_health_08_margin_income_agr_test;
pub mod example_02_salary_01_working_shift_week_test;
pub mod example_02_salary_02_working_shift_time_test;
pub mod example_02_salary_03_min_monthly_wage_test;
pub mod example_02_salary_04_min_hourly_wage_test;
pub mod example_03_social_01_max_annuals_basis_test;
pub mod example_03_social_02_factor_employer_test;
pub mod example_03_social_03_factor_employer_higher_test;
pub mod example_03_social_04_factor_employee_test;
pub mod example_03_social_05_factor_employee_garant_test;
pub mod example_03_social_06_factor_employee_reduce_test;
pub mod example_03_social_07_margin_income_emp_test;
pub mod example_03_social_08_margin_income_agr_test;
pub mod example_04_taxing_01_allowance_payer_test;
pub mod example_04_taxing_02_allowance_disab1st_test;
pub mod example_04_taxing_03_allowance_disab2nd_test;
pub mod example_04_taxing_04_allowance_disab3rd_test;
pub mod example_04_taxing_05_allowance_study_test;
pub mod example_04_taxing_06_allowance_child1st_test;
pub mod example_04_taxing_07_allowance_child2nd_test;
pub mod example_04_taxing_08_allowance_child3rd_test;
pub mod example_04_taxing_09_factor_advances_test;
pub mod example_04_taxing_10_factor_withhold_test;
pub mod example_04_taxing_11_factor_solidary_test;
pub mod example_04_taxing_12_factor_taxrate2_test;
pub mod example_04_taxing_13_min_amount_of_tax_bonus_test;
pub mod example_04_taxing_14_max_amount_of_tax_bonus_test;
pub mod example_04_taxing_15_margin_income_of_tax_bonus_test;
pub mod example_04_taxing_16_margin_income_of_rounding_test;
pub mod example_04_taxing_17_margin_income_of_withhold_test;
pub mod example_04_taxing_18_margin_income_of_solidary_test;
pub mod example_04_taxing_19_margin_income_of_taxrate2_test;
pub mod example_04_taxing_20_margin_income_of_wth_emp_test;
pub mod example_04_taxing_21_margin_income_of_wth_agr_test;
pub mod service_examples_int_tests;
pub mod service_examples_dec_tests;
pub mod service_report_examples_int_tests;
pub mod service_report_examples_dec_tests;
pub mod service_report_examples_tests;
pub mod example_bundle_failure_2009_test;
